#!/usr/bin/env python3
import json, urllib.parse, datetime, hashlib, zlib, os, gzip

try:
    mapping = json.loads(open('src/_mapping.json', 'rt', encoding='utf-8').read())
except (SystemExit, KeyboardInterrupt):
    raise
except:
    mapping = {}
try:
    comments = json.loads(open('src/_comments.json', 'rt', encoding='utf-8').read())
except (SystemExit, KeyboardInterrupt):
    raise
except:
    comments = {}

def read_c():
    for w in os.listdir('/var/log/nginx'):
        if w.startswith('comments') and w.endswith('.gz'):
            with gzip.open(os.path.join('/var/log/nginx', w)) as f:
                data = f.read().decode('utf-8')
                for q in data.strip().split('\n'):
                    yield q
        elif w.startswith('comments'):
            with open(os.path.join('/var/log/nginx', w), 'rt', encoding='utf-8') as f:
                data = f.read()
                for q in data.strip().split('\n'):
                    yield q

for x in read_c():
    try:
        x = json.loads(x)
        time = datetime.datetime.strptime(x['time'], "%Y-%m-%dT%H:%M:%S%z")
        ip = x['ip']
        referer = x['referer']
        user_agent = x['ua']
        y = urllib.parse.parse_qs(x['body'], keep_blank_values=True)
        orig_name, = y['name']
        name = orig_name
        trip = None
        if '#' in name:
            name, trip = name.split('#', 1)
            m = hashlib.sha256()
            m.update(open('src/_salt.txt', 'rb').read().strip())
            m.update(orig_name.encode('utf-8'))
            trip = m.hexdigest()
        pr, = y['pm']
        pb, = y['comment']
        cp, = y['captcha']
        if not name: name = 'Anonymous'
    except (SystemExit, KeyboardInterrupt):
        raise
    except:
        continue
    if not pr and not pb:
        continue
    print(time, '\t', orig_name, trip, '\t\t\t', ip, user_agent)
    if not referer.startswith('https://pavluk.org/'):
        print('Bad referer', pr, pb, cp)
        continue
    referer = referer[len('https://pavluk.org/'):]
    if referer not in mapping.keys():
        print('Bad referer 2', pr, pb, cp)
        continue
    referer = mapping[referer]
    print(referer)
    email = zlib.decompress(b'x\x9cK\xceH\xac\xccIMLs(H,\xcb)\xcd\xd6\xcb/J\x07\x00K\x9e\x07\x87').decode('utf-8')
    if cp != email and cp != '-human@'.join(email.split('@')):
        print('Bad captcha:', repr(cp))
    if pr:
        print('Private:')
        print(pr)
    if not cp or cp.endswith('@gmail.com') or cp.endswith('aiahouse.hu') or cp.startswith('no-reply'):
        continue
    if pb:
        print('Public:')
        print(pb)
        if input('Commit? ') in 'yY':
            if referer not in comments: comments[referer] = []
            comments[referer].append({
                'time': time.isoformat(),
                'name': name,
                'trip': trip,
                'comment': pb,
            })
    else:
        input('Press enter to continue... ')

 
with open('src/_comments.json', 'wt', encoding='utf-8') as f:
    f.write(json.dumps(comments))

if input('Clear history? ') in 'yY':
    open('/var/log/nginx/comments.log', 'w')

